@@ -29,14 +29,14 @@ primary_column media_id => {
 
 The image/video file.
 
-Defaults to empty string.
+Is nullable.
 
 =cut
 
 unique_column file => {
     data_type     => "varchar",
-    default_value => "",
-    size          => 255
+    size          => 255,
+    is_nullable   => 1,
 };
 
 =head2 uri
@@ -88,7 +88,7 @@ FK on L<Interchange6::Schema::Result::User/users_id>.
 =cut
 
 column author_users_id =>
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 };
+  { data_type => "integer", is_nullable => 1 };
 
 =head2 created
 
@@ -129,7 +129,15 @@ FK on L<Interchange6::Schema::Result::MediaType/media_types_id>.
 =cut
 
 column media_types_id =>
-  { data_type => "integer", is_foreign_key => 1 };
+  { data_type => "integer" };
+
+=head2 priority
+
+Priority for display. Defaults to 0.
+
+=cut
+
+column priority => { data_type => "integer", default_value => 0 };
 
 =head1 UNIQUE CONSTRAINTS
 
@@ -189,6 +197,19 @@ has_many
   "media_id",
   { cascade_copy => 0, cascade_delete => 0 };
 
+=head2 media_navigations
+
+Type: has_many
+
+Related object: L<Interchange6::Schema::Result::MediaNavigation>
+
+=cut
+
+has_many
+  media_navigations => "Interchange6::Schema::Result::MediaNavigation",
+  "media_id",
+  { cascade_copy => 0, cascade_delete => 0 };
+
 =head2 products
 
 Type: many_to_many with product.
