@@ -19,7 +19,7 @@ via L</orderline> relationship.
 
 =cut
 
-column orderlines_id => { data_type => "integer", is_foreign_key => 1 };
+column orderlines_id => { data_type => "integer" };
 
 =head2 addresses_id
 
@@ -28,7 +28,7 @@ via L</address> relationship.
 
 =cut
 
-column addresses_id => { data_type => "integer", is_foreign_key => 1 };
+column addresses_id => { data_type => "integer" };
 
 =head2 shipments_id
 
@@ -37,7 +37,16 @@ via L</shipment> relationship.
 
 =cut
 
-column shipments_id => { data_type => "integer", is_foreign_key => 1 };
+column shipments_id => { data_type => "integer" };
+
+=head2 quantity
+
+The partial or full quantity shipped for the related
+L<Interchange6::Schema::Result::Orderline> in this shipment.
+
+=cut
+
+column quantity => { data_type => "integer" };
 
 =head1 PRIMARY KEY
 
@@ -51,11 +60,13 @@ than one consignment.
 
 =item * L</addresses_id>
 
+=item * L</shipments_id>
+
 =back
 
 =cut
 
-primary_key "orderlines_id", "addresses_id";
+primary_key "orderlines_id", "addresses_id", "shipments_id";
 
 =head1 RELATIONS
 
@@ -114,4 +125,16 @@ sub delete {
         "OrderlinesShipping rows cannot be deleted");
 }
 
+=head2 partial_shipment
+
+If L<Interchange6::Schema::Result::Orderline/quantity> is greater than
+L</quantity> then return 1. Otherwise returns 0.
+
+=cut
+
+sub partial_shipment {
+    my $self = shift;
+    return $self->orderline->quantity > $self->quantity ? 1 : 0;
+}
+
 1;
